@@ -9,7 +9,5 @@ from .priors import kde
 from .session import session
 from .asy_peakbag import asymp_spec_model, asymptotic_fit
 from .peakbag import peakbag
-from .ellone import ellone
 from .star import star
 from .mcmc import mcmc
-from .mcmc import nested
\ No newline at end of file
